==> kubernetes-model-3.0.1-sources.jar: annotations/io/fabric8/openshift/api/model/NamedRoleBindingBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class NamedRoleBindingBuilder extends NamedRoleBindingFluentImpl<NamedRoleBindingBuilder> implements VisitableBuilder<NamedRoleBinding,NamedRoleBindingBuilder>{

    NamedRoleBindingFluent<?> fluent;
    Boolean validationEnabled;

    public NamedRoleBindingBuilder(){
            this(true);
    }
    public NamedRoleBindingBuilder(Boolean validationEnabled){
            this(new NamedRoleBinding(), validationEnabled);
    }
    public NamedRoleBindingBuilder(NamedRoleBindingFluent<?> fluent){
            this(fluent, true);
    }
    public NamedRoleBindingBuilder(NamedRoleBindingFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new NamedRoleBinding(), validationEnabled);
    }
    public NamedRoleBindingBuilder(NamedRoleBindingFluent<?> fluent,NamedRoleBinding instance){
            this(fluent, instance, true);
    }
    public NamedRoleBindingBuilder(NamedRoleBindingFluent<?> fluent,NamedRoleBinding instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withName(instance.getName()); 
            fluent.withRoleBinding(instance.getRoleBinding()); 
            this.validationEnabled = validationEnabled; 
    }
    public NamedRoleBindingBuilder(NamedRoleBinding instance){
            this(instance,true);
    }
    public NamedRoleBindingBuilder(NamedRoleBinding instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withName(instance.getName()); 
            this.withRoleBinding(instance.getRoleBinding()); 
            this.validationEnabled = validationEnabled; 
    }

    public NamedRoleBinding build(){
            NamedRoleBinding buildable = new NamedRoleBinding(fluent.getName(),fluent.getRoleBinding());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            NamedRoleBindingBuilder that = (NamedRoleBindingBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-4.1.0-sources.jar: annotations/io/fabric8/openshift/api/model/NamedRoleBindingBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
import javax.validation.Validator;

public class NamedRoleBindingBuilder extends NamedRoleBindingFluentImpl<NamedRoleBindingBuilder> implements VisitableBuilder<NamedRoleBinding,NamedRoleBindingBuilder>{

    NamedRoleBindingFluent<?> fluent;
    Boolean validationEnabled;
    Validator validator;

    public NamedRoleBindingBuilder(){
            this(true);
    }
    public NamedRoleBindingBuilder(Boolean validationEnabled){
            this(new NamedRoleBinding(), validationEnabled);
    }
    public NamedRoleBindingBuilder(NamedRoleBindingFluent<?> fluent){
            this(fluent, true);
    }
    public NamedRoleBindingBuilder(NamedRoleBindingFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new NamedRoleBinding(), validationEnabled);
    }
    public NamedRoleBindingBuilder(NamedRoleBindingFluent<?> fluent,NamedRoleBinding instance){
            this(fluent, instance, true);
    }
    public NamedRoleBindingBuilder(NamedRoleBindingFluent<?> fluent,NamedRoleBinding instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withName(instance.getName()); 
            fluent.withRoleBinding(instance.getRoleBinding()); 
            this.validationEnabled = validationEnabled; 
    }
    public NamedRoleBindingBuilder(NamedRoleBinding instance){
            this(instance,true);
    }
    public NamedRoleBindingBuilder(NamedRoleBinding instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withName(instance.getName()); 
            this.withRoleBinding(instance.getRoleBinding()); 
            this.validationEnabled = validationEnabled; 
    }
    public NamedRoleBindingBuilder(Validator validator){
            this(new NamedRoleBinding(), true);
    }
    public NamedRoleBindingBuilder(NamedRoleBindingFluent<?> fluent,NamedRoleBinding instance,Validator validator){
            this.fluent = fluent; 
            fluent.withName(instance.getName()); 
            fluent.withRoleBinding(instance.getRoleBinding()); 
            this.validator = validator;
            this.validationEnabled = validator != null; 
    }
    public NamedRoleBindingBuilder(NamedRoleBinding instance,Validator validator){
            this.fluent = this; 
            this.withName(instance.getName()); 
            this.withRoleBinding(instance.getRoleBinding()); 
            this.validator = validator; 
            this.validationEnabled = validator != null; 
    }

    public NamedRoleBinding build(){
            NamedRoleBinding buildable = new NamedRoleBinding(fluent.getName(),fluent.getRoleBinding());
            if (validationEnabled) {io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable, validator);}
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            NamedRoleBindingBuilder that = (NamedRoleBindingBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
